@@ -5,11 +5,12 @@ use ibc::ics03_connection::connection::ConnectionEnd;
 use ibc::ics04_channel::channel::Order;
 use ibc::ics24_host::identifier::{ChainId, ChannelId, ClientId, ConnectionId, PortId};
 use ibc::Height;
+use ibc_relayer::chain::handle::ChainHandle;
 use ibc_relayer::channel::{Channel, ChannelSide};
 
 use crate::cli_utils::ChainHandlePair;
 use crate::conclude::Output;
-use crate::error::{Error, Kind};
+use crate::error::Error;
 use crate::prelude::*;
 
 macro_rules! tx_chan_cmd {
@@ -35,7 +36,7 @@ macro_rules! tx_chan_cmd {
 
         info!("Message {}: {:?}", $dbg_string, channel);
 
-        let res: Result<IbcEvent, Error> = channel.$func().map_err(|e| Kind::Tx.context(e).into());
+        let res: Result<IbcEvent, Error> = channel.$func().map_err(Error::channel);
 
         match res {
             Ok(receipt) => Output::success(receipt).exit(),
@@ -67,32 +68,52 @@ pub struct TxRawChanOpenInitCmd {
 
 impl Runnable for TxRawChanOpenInitCmd {
     fn run(&self) {
-        tx_chan_cmd!(
-            "ChanOpenInit",
-            build_chan_open_init_and_send,
-            self,
-            |chains: ChainHandlePair, dst_connection: ConnectionEnd| {
-                Channel {
-                    connection_delay: Default::default(),
-                    ordering: self.order,
-                    a_side: ChannelSide::new(
-                        chains.src,
-                        ClientId::default(),
-                        ConnectionId::default(),
-                        self.src_port_id.clone(),
-                        None,
-                    ),
-                    b_side: ChannelSide::new(
-                        chains.dst.clone(),
-                        dst_connection.client_id().clone(),
-                        self.dst_conn_id.clone(),
-                        self.dst_port_id.clone(),
-                        None,
-                    ),
-                    version: None,
-                }
-            }
-        );
+        let config = app_config();
+
+        let chains = match ChainHandlePair::spawn(&config, &self.src_chain_id, &self.dst_chain_id) {
+            Ok(chains) => chains,
+            Err(e) => return Output::error(format!("{}", e)).exit(),
+        };
+
+        // Retrieve the connection
+        let dst_connection = match chains
+            .dst
+            .query_connection(&self.dst_conn_id, Height::default())
+        {
+            Ok(connection) => connection,
+            Err(e) => return Output::error(format!("{}", e)).exit(),
+        };
+
+        let channel = Channel {
+            connection_delay: Default::default(),
+            ordering: self.order,
+            a_side: ChannelSide::new(
+                chains.src,
+                ClientId::default(),
+                ConnectionId::default(),
+                self.src_port_id.clone(),
+                None,
+            ),
+            b_side: ChannelSide::new(
+                chains.dst,
+                dst_connection.client_id().clone(),
+                self.dst_conn_id.clone(),
+                self.dst_port_id.clone(),
+                None,
+            ),
+            version: None,
+        };
+
+        info!("Message ChanOpenInit: {:?}", channel);
+
+        let res: Result<IbcEvent, Error> = channel
+            .build_chan_open_init_and_send()
+            .map_err(Error::channel);
+
+        match res {
+            Ok(receipt) => Output::success(receipt).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
+        }
     }
 }
 
@@ -131,6 +152,53 @@ pub struct TxRawChanOpenTryCmd {
 
 impl Runnable for TxRawChanOpenTryCmd {
     fn run(&self) {
+        let config = app_config();
+
+        let chains = match ChainHandlePair::spawn(&config, &self.src_chain_id, &self.dst_chain_id) {
+            Ok(chains) => chains,
+            Err(e) => return Output::error(format!("{}", e)).exit(),
+        };
+
+        // Retrieve the connection
+        let dst_connection = match chains
+            .dst
+            .query_connection(&self.dst_conn_id, Height::default())
+        {
+            Ok(connection) => connection,
+            Err(e) => return Output::error(format!("{}", e)).exit(),
+        };
+
+        let channel = Channel {
+            connection_delay: Default::default(),
+            ordering: Order::default(),
+            a_side: ChannelSide::new(
+                chains.src,
+                ClientId::default(),
+                ConnectionId::default(),
+                self.src_port_id.clone(),
+                Some(self.src_chan_id.clone()),
+            ),
+            b_side: ChannelSide::new(
+                chains.dst,
+                dst_connection.client_id().clone(),
+                self.dst_conn_id.clone(),
+                self.dst_port_id.clone(),
+                self.dst_chan_id.clone(),
+            ),
+            version: None,
+        };
+
+        info!("Message ChanOpenTry: {:?}", channel);
+
+        let res: Result<IbcEvent, Error> = channel
+            .build_chan_open_try_and_send()
+            .map_err(Error::channel);
+
+        match res {
+            Ok(receipt) => Output::success(receipt).exit(),
+            Err(e) => Output::error(format!("{}", e)).exit(),
+        }
+
         tx_chan_cmd!(
             "ChanOpenTry",
             build_chan_open_try_and_send,
@@ -147,7 +215,7 @@ impl Runnable for TxRawChanOpenTryCmd {
                         Some(self.src_chan_id.clone()),
                     ),
                     b_side: ChannelSide::new(
-                        chains.dst.clone(),
+                        chains.dst,
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
@@ -212,7 +280,7 @@ impl Runnable for TxRawChanOpenAckCmd {
                         Some(self.src_chan_id.clone()),
                     ),
                     b_side: ChannelSide::new(
-                        chains.dst.clone(),
+                        chains.dst,
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
@@ -277,7 +345,7 @@ impl Runnable for TxRawChanOpenConfirmCmd {
                         Some(self.src_chan_id.clone()),
                     ),
                     b_side: ChannelSide::new(
-                        chains.dst.clone(),
+                        chains.dst,
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
@@ -342,7 +410,7 @@ impl Runnable for TxRawChanCloseInitCmd {
                         Some(self.src_chan_id.clone()),
                     ),
                     b_side: ChannelSide::new(
-                        chains.dst.clone(),
+                        chains.dst,
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
@@ -407,7 +475,7 @@ impl Runnable for TxRawChanCloseConfirmCmd {
                         Some(self.src_chan_id.clone()),
                     ),
                     b_side: ChannelSide::new(
-                        chains.dst.clone(),
+                        chains.dst,
                         dst_connection.client_id().clone(),
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
